@@ -363,8 +363,8 @@ class HumanName(object):
     
     @property
     def full_name(self):
-        """The name string to be parsed."""
-        return self._full_name
+        """The string output of the HumanName instance."""
+        return self.__str__()
     
     @full_name.setter
     def full_name(self, value):
@@ -413,9 +413,9 @@ class HumanName(object):
         The content of parenthesis or quotes in the name will be added to the 
         nicknames list. This happens before any other processing of the name.
         
-        Single quotes cannot span white space characters to allow for single
-        quotes in names like O'Connor. Double quotes and parenthesis can span
-        white space.
+        Single quotes cannot span white space characters and must border
+        white space to allow for quotes in names like O'Connor and Kawai'ae'a.
+        Double quotes and parenthesis can span white space.
         
         Loops through 3 :py:data:`~nameparser.config.regexes.REGEXES`; 
         `quoted_word`, `double_quotes` and `parenthesis`.
@@ -480,8 +480,8 @@ class HumanName(object):
         # break up full_name by commas
         parts = [x.strip() for x in self._full_name.split(",")]
         
-        log.debug("full_name: {0}".format(self._full_name))
-        log.debug("parts: {0}".format(parts))
+        log.debug("full_name: %s", self._full_name)
+        log.debug("parts: %s", parts)
         
         if len(parts) == 1:
             
@@ -538,7 +538,7 @@ class HumanName(object):
                 
                 self.suffix_list += parts[1:]
                 pieces = self.parse_pieces(parts[0].split(' '))
-                log.debug("pieces: {0}".format(u(pieces)))
+                log.debug("pieces: %s", u(pieces))
                 for i, piece in enumerate(pieces):
                     try:
                         nxt = pieces[i + 1]
@@ -568,7 +568,7 @@ class HumanName(object):
                 #      parts[0],      parts[1],              parts[2:...]
                 pieces = self.parse_pieces(parts[1].split(' '), 1)
                 
-                log.debug("pieces: {0}".format(u(pieces)))
+                log.debug("pieces: %s", u(pieces))
                 
                 # lastname part may have suffixes in it
                 lastname_pieces = self.parse_pieces(parts[0].split(' '), 1)
@@ -605,7 +605,7 @@ class HumanName(object):
                     pass
                 
         if len(self) < 0:
-            log.info("Unparsable: \"{}\" ".format(self.original))
+            log.info("Unparsable: \"%s\" ", self.original)
         else:
             self.unparsable = False
         self.post_process()
@@ -806,7 +806,7 @@ class HumanName(object):
                         new_piece = ' '.join(pieces[i:])
                         pieces = pieces[:i] + [new_piece]
 
-        log.debug("pieces: {0}".format(pieces))
+        log.debug("pieces: %s", pieces)
         return pieces
     
     
